/* global wp, jQuery */
/**
 * File customizer.js.
 *
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 */

(function($) {
    // Site title and description.
    wp.customize('blogname', function(value) {
        value.bind(function(to) {
            $('.site-title a').text(to);
        });
    });
    wp.customize('blogdescription', function(value) {
        value.bind(function(to) {
            $('.site-description').text(to);
        });
    });

    // Header text color.
    wp.customize('header_textcolor', function(value) {
        value.bind(function(to) {
            if ('blank' === to) {
                $('.site-title, .site-description').css({
                    clip: 'rect(1px, 1px, 1px, 1px)',
                    position: 'absolute',
                });
            } else {
                $('.site-title, .site-description').css({
                    clip: 'auto',
                    position: 'relative',
                });
                $('.site-title a, .site-description').css({
                    color: to,
                });
            }
        });
    });

    const enterpriseup_section_lists = ['banner', 'about', 'blog', 'team', 'newsletter', 'service', 'features', 'gallery'];
    enterpriseup_section_lists.forEach(enterpriseup_homepage_scroll_preview);

    function enterpriseup_homepage_scroll_preview(item, index) {
        // Collect information from customize-controls.js about which panels are opening.
        wp.customize.bind('preview-ready', function() {

            // Initially hide the theme option placeholders on load.
            $('.panel-placeholder').hide();
            item = item.replace(/-/g, '_');
            wp.customize.preview.bind(item, function(data) {
                // Only on the front page.
                if (!$('body').hasClass('home')) {
                    return;
                }

                // When the section is expanded, show and scroll to the content placeholders, exposing the edit links.
                if (true === data.expanded) {
                    $('html, body').animate({
                        'scrollTop': $('#enterpriseup_' + item + '_section').position().top
                    });
                }
            });

        });
    }

    // Gallery Section.
    wp.customize('enterpriseup_gallery_title', function(value) {
        value.bind(function(to) {
            $('#enterpriseup_gallery_section h3.section-title').text(to);
        });
    });
    wp.customize('enterpriseup_gallery_text', function(value) {
        value.bind(function(to) {
            $('#enterpriseup_gallery_section p.section-subtitle').text(to);
        });
    });
    wp.customize('enterpriseup_gallery_button_label', function(value) {
        value.bind(function(to) {
            $('#enterpriseup_gallery_section .enterpriseup-gallery-view-all a').text(to);
        });
    });

    // Services Section.
    wp.customize('enterpriseup_service_title', function(value) {
        value.bind(function(to) {
            $('#enterpriseup_service_section .section-title').text(to);
        });
    });
    wp.customize('enterpriseup_service_short_description', function(value) {
        value.bind(function(to) {
            $('#enterpriseup_service_section .section-subtitle').text(to);
        });
    });
    wp.customize('enterpriseup_service_button_label', function(value) {
        value.bind(function(to) {
            $('#enterpriseup_service_section .enterpriseup-button-alternate a').text(to);
        });
    });

    // About Section.
    wp.customize('enterpriseup_about_button_label', function(value) {
        value.bind(function(to) {
            $('#enterpriseup_about_section .enterpriseup-button a').text(to);
        });
    });

    // Features Section.
    wp.customize('enterpriseup_features_title', function(value) {
        value.bind(function(to) {
            $('#enterpriseup_features_section .section-title').text(to);
        });
    });
    wp.customize('enterpriseup_features_text', function(value) {
        value.bind(function(to) {
            $('#enterpriseup_features_section .section-subtitle').text(to);
        });
    });

    // Team Section.
    wp.customize('enterpriseup_team_section_title', function(value) {
        value.bind(function(to) {
            $('#enterpriseup_team_section .section-title').text(to);
        });
    });
    wp.customize('enterpriseup_team_section_text', function(value) {
        value.bind(function(to) {
            $('#enterpriseup_team_section .section-subtitle').text(to);
        });
    });
    wp.customize('enterpriseup_team_button_label', function(value) {
        value.bind(function(to) {
            $('#enterpriseup_team_section .enterpriseup-teams-view-all a').text(to);
        });
    });

    // Blog Section.
    wp.customize('enterpriseup_blog_title', function(value) {
        value.bind(function(to) {
            $('#enterpriseup_blog_section h3.section-title').text(to);
        });
    });
    wp.customize('enterpriseup_blog_text', function(value) {
        value.bind(function(to) {
            $('#enterpriseup_blog_section p.section-subtitle').text(to);
        });
    });
    wp.customize('enterpriseup_blog_button_label', function(value) {
        value.bind(function(to) {
            $('#enterpriseup_blog_section .enterpriseup-blog-view-all a').text(to);
        });
    });

    // Newsletter Section.
    wp.customize('enterpriseup_newsletter_title', function(value) {
        value.bind(function(to) {
            $('#enterpriseup_newsletter_section .enterpriseup-newsletter-title').text(to);
        });
    });
    wp.customize('enterpriseup_newsletter_content', function(value) {
        value.bind(function(to) {
            $('#enterpriseup_newsletter_section .enterpriseup-newsletter-text p').text(to);
        });
    });

}(jQuery));