<?php
/**
 * Banner Section
 *
 * @package EnterpriseUp
 */

$wp_customize->add_section(
	'enterpriseup_banner_section',
	array(
		'panel'		=> 'enterpriseup_front_page_options',
		'title'		=> esc_html__( 'Banner Slider Section', 'enterpriseup' ),
		'priority'	=> 10,
	)
);

// Banner Section - Enable Section.
$wp_customize->add_setting(
	'enterpriseup_enable_banner_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'enterpriseup_sanitize_switch',
	)
);

$wp_customize->add_control(
	new EnterpriseUp_Toggle_Switch_Custom_Control(
		$wp_customize,
		'enterpriseup_enable_banner_section',
		array(
			'label'    => esc_html__( 'Enable Banner Section', 'enterpriseup' ),
			'section'  => 'enterpriseup_banner_section',
			'settings' => 'enterpriseup_enable_banner_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'enterpriseup_enable_banner_section',
		array(
			'selector' => '#enterpriseup_banner_section .section-link',
			'settings' => 'enterpriseup_enable_banner_section',
		)
	);
}

// Banner Section - Content Type.
$wp_customize->add_setting(
	'enterpriseup_banner_content',
	array(
		'default'           => 'page',
		'sanitize_callback' => 'enterpriseup_sanitize_select',
	)
);

$wp_customize->add_control(
	'enterpriseup_banner_content',
	array(
		'label'           => esc_html__( 'Select Content Type', 'enterpriseup' ),
		'section'         => 'enterpriseup_banner_section',
		'settings'        => 'enterpriseup_banner_content',
		'type'            => 'select',
		'active_callback' => 'enterpriseup_is_banner_section_enabled',
		'choices'         => array(
			'page' => esc_html__( 'Page', 'enterpriseup' ),
			'post' => esc_html__( 'Post', 'enterpriseup' ),
		),
	)
);

for ( $i = 1; $i <= 3; $i++ ) {

	// Banner Section - Content Type Post.
	$wp_customize->add_setting(
		'enterpriseup_banner_content_post_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'enterpriseup_banner_content_post_' . $i,
		array(
			'label'           => esc_html__( 'Select Post ', 'enterpriseup' ) . $i,
			'section'         => 'enterpriseup_banner_section',
			'settings'        => 'enterpriseup_banner_content_post_' . $i,
			'active_callback' => 'enterpriseup_is_banner_section_and_content_type_post_enabled',
			'type'            => 'select',
			'choices'         => enterpriseup_get_post_choices(),
		)
	);

	// Banner Section - Content Type Page.
	$wp_customize->add_setting(
		'enterpriseup_banner_content_page_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'enterpriseup_banner_content_page_' . $i,
		array(
			'label'           => esc_html__( 'Select Page ', 'enterpriseup' ) . $i,
			'section'         => 'enterpriseup_banner_section',
			'settings'        => 'enterpriseup_banner_content_page_' . $i,
			'active_callback' => 'enterpriseup_is_banner_section_and_content_type_page_enabled',
			'type'            => 'select',
			'choices'         => enterpriseup_get_page_choices(),
		)
	);

	// Banner Section - Button Label.
	$wp_customize->add_setting(
		'enterpriseup_banner_button_label' . $i,
		array(
			'default'           => __( 'Read More', 'enterpriseup' ),
			'sanitize_callback' => 'sanitize_text_field',
			'transport'         => 'refresh',
		)
	);

	$wp_customize->add_control(
		'enterpriseup_banner_button_label' . $i,
		array(
			'label'           => esc_html__( 'Button Label ', 'enterpriseup' ) . $i,
			'section'         => 'enterpriseup_banner_section',
			'settings'        => 'enterpriseup_banner_button_label' . $i,
			'type'            => 'text',
			'active_callback' => 'enterpriseup_is_banner_section_enabled',
		)
	);

	// Banner Section - Button Link.
	$wp_customize->add_setting(
		'enterpriseup_banner_button_link' . $i,
		array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		)
	);

	$wp_customize->add_control(
		'enterpriseup_banner_button_link' . $i,
		array(
			'label'           => esc_html__( 'Button Link ', 'enterpriseup' ) . $i,
			'section'         => 'enterpriseup_banner_section',
			'settings'        => 'enterpriseup_banner_button_link' . $i,
			'type'            => 'url',
			'active_callback' => 'enterpriseup_is_banner_section_enabled',
		)
	);

}
