<?php
/**
 * Service Section
 *
 * @package EnterpriseUp
 */

$wp_customize->add_section(
	'enterpriseup_service_section',
	array(
		'panel' 	=> 'enterpriseup_front_page_options',
		'title' 	=> esc_html__( 'Service Section', 'enterpriseup' ),
		'priority'	=> 20,
	)
);

// Service Section - Enable Section.
$wp_customize->add_setting(
	'enterpriseup_enable_service_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'enterpriseup_sanitize_switch',
	)
);

$wp_customize->add_control(
	new EnterpriseUp_Toggle_Switch_Custom_Control(
		$wp_customize,
		'enterpriseup_enable_service_section',
		array(
			'label'    => esc_html__( 'Enable Service Section', 'enterpriseup' ),
			'section'  => 'enterpriseup_service_section',
			'settings' => 'enterpriseup_enable_service_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'enterpriseup_enable_service_section',
		array(
			'selector' => '#enterpriseup_service_section .section-link',
			'settings' => 'enterpriseup_enable_service_section',
		)
	);
}

// Service Section - Section Title.
$wp_customize->add_setting(
	'enterpriseup_service_title',
	array(
		'default'           => __( 'What We Do For You', 'enterpriseup' ),
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'postMessage',
	)
);

$wp_customize->add_control(
	'enterpriseup_service_title',
	array(
		'label'           => esc_html__( 'Section Title', 'enterpriseup' ),
		'section'         => 'enterpriseup_service_section',
		'settings'        => 'enterpriseup_service_title',
		'type'            => 'text',
		'active_callback' => 'enterpriseup_is_service_section_enabled',
	)
);

// Service Section - Section Short Description.
$wp_customize->add_setting(
	'enterpriseup_service_short_description',
	array(
		'default'           => '',
		'sanitize_callback' => 'wp_kses_post',
		'transport'         => 'postMessage',
	)
);

$wp_customize->add_control(
	'enterpriseup_service_short_description',
	array(
		'label'           => esc_html__( 'Section Short Description', 'enterpriseup' ),
		'section'         => 'enterpriseup_service_section',
		'settings'        => 'enterpriseup_service_short_description',
		'type'            => 'textarea',
		'active_callback' => 'enterpriseup_is_service_section_enabled',
	)
);

// Service Section - Button Label.
$wp_customize->add_setting(
	'enterpriseup_service_button_label',
	array(
		'default'           => __( 'View All Services', 'enterpriseup' ),
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'postMessage',
	)
);

$wp_customize->add_control(
	'enterpriseup_service_button_label',
	array(
		'label'           => esc_html__( 'Button Label', 'enterpriseup' ),
		'section'         => 'enterpriseup_service_section',
		'settings'        => 'enterpriseup_service_button_label',
		'type'            => 'text',
		'active_callback' => 'enterpriseup_is_service_section_enabled',
	)
);

// Service Section - Button Link.
$wp_customize->add_setting(
	'enterpriseup_service_button_link',
	array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control(
	'enterpriseup_service_button_link',
	array(
		'label'           => esc_html__( 'Button Link', 'enterpriseup' ),
		'section'         => 'enterpriseup_service_section',
		'settings'        => 'enterpriseup_service_button_link',
		'type'            => 'url',
		'active_callback' => 'enterpriseup_is_service_section_enabled',
	)
);

// Service Section - Content Type.
$wp_customize->add_setting(
	'enterpriseup_service_content_type',
	array(
		'default'           => 'page',
		'sanitize_callback' => 'enterpriseup_sanitize_select',
	)
);

$wp_customize->add_control(
	'enterpriseup_service_content_type',
	array(
		'label'           => esc_html__( 'Select Content Type', 'enterpriseup' ),
		'section'         => 'enterpriseup_service_section',
		'settings'        => 'enterpriseup_service_content_type',
		'type'            => 'select',
		'active_callback' => 'enterpriseup_is_service_section_enabled',
		'choices'         => array(
			'page' => esc_html__( 'Page', 'enterpriseup' ),
			'post' => esc_html__( 'Post', 'enterpriseup' ),
		),
	)
);

// List out selected number of fields.
for ( $i = 1; $i <= 4; $i++ ) {
	// Service Section - Select Post.
	$wp_customize->add_setting(
		'enterpriseup_service_content_post_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'enterpriseup_service_content_post_' . $i,
		array(
			'label'           => esc_html__( 'Select Post ', 'enterpriseup' ) . $i,
			'section'         => 'enterpriseup_service_section',
			'settings'        => 'enterpriseup_service_content_post_' . $i,
			'active_callback' => 'enterpriseup_is_service_section_and_content_type_post_enabled',
			'type'            => 'select',
			'choices'         => enterpriseup_get_post_choices(),
		)
	);

	// Service Section - Select Page.
	$wp_customize->add_setting(
		'enterpriseup_service_content_page_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'enterpriseup_service_content_page_' . $i,
		array(
			'label'           => esc_html__( 'Select Page ', 'enterpriseup' ) . $i,
			'section'         => 'enterpriseup_service_section',
			'settings'        => 'enterpriseup_service_content_page_' . $i,
			'active_callback' => 'enterpriseup_is_service_section_and_content_type_page_enabled',
			'type'            => 'select',
			'choices'         => enterpriseup_get_page_choices(),
		)
	);

}
