<?php

if ( ! get_theme_mod( 'enterpriseup_enable_gallery_section', false ) ) {
	return;
}

$content_ids   = array();
$content_count = get_theme_mod( 'enterpriseup_gallery_count', 6 );
$content_type  = get_theme_mod( 'enterpriseup_gallery_content_type', 'page' );

if ( in_array( $content_type, array( 'post', 'page' ) ) ) {

	for ( $i = 1; $i <= $content_count; $i++ ) {
		$content_ids[] = get_theme_mod( 'enterpriseup_gallery_content_' . $content_type . '_' . $i );
	}

	$args = array(
		'post_type'           => $content_type,
		'post__in'            => array_filter( $content_ids ),
		'orderby'             => 'post__in',
		'posts_per_page'      => absint( $content_count ),
		'ignore_sticky_posts' => true,
	);

}

$args = apply_filters( 'enterpriseup_gallery_section_args', $args );

enterpriseup_render_gallery_section( $args );

/**
 * Render Gallery Section.
 */
function enterpriseup_render_gallery_section( $args ) {
	$section_title = get_theme_mod( 'enterpriseup_gallery_title', __( 'Our Gallery', 'enterpriseup' ) );
	$section_text  = get_theme_mod( 'enterpriseup_gallery_text' );
	$button_label  = get_theme_mod( 'enterpriseup_gallery_button_label', __( 'View All', 'enterpriseup' ) );
	$button_link   = get_theme_mod( 'enterpriseup_gallery_button_link' );
	$button_link   = ! empty( $button_link ) ? $button_link : '#';

	$query = new WP_Query( $args );
	if ( $query->have_posts() ) :
		?>
		<section id="enterpriseup_gallery_section" class="enterpriseup-frontpage-section enterpriseup-gallery-section">
			<?php
			if ( is_customize_preview() ) :
				enterpriseup_section_link( 'enterpriseup_gallery_section' );
			endif;
			?>
			<div class="ascendoor-wrapper">
				<?php if ( ! empty( $section_title || $section_text ) ) : ?>
					<div class="section-header-subtitle">
						<h3 class="section-title"><?php echo esc_html( $section_title ); ?></h3>
						<p class="section-subtitle"><?php echo esc_html( $section_text ); ?></p>
					</div>
				<?php endif; ?>
				<div class="enterpriseup-section-body">
					<div class="enterpriseup-gallery-section-wrapper">
					<?php
					while ( $query->have_posts() ) :
						$query->the_post();
						?>
							<div class="enterpriseup-gallery-single">
								<div class="enterpriseup-gallery-img">
									<a href="<?php the_permalink(); ?>">
										<img src="<?php echo esc_url( get_the_post_thumbnail_url( get_the_ID(), 'full' ) ); ?>">
									</a>
								</div>
								<div class="enterpriseup-gallery-detail">
									<h3 class="enterpriseup-gallery-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
									<p class="enterpriseup-content"><?php echo wp_kses_post( get_the_excerpt() ); ?></p>
								</div>
							</div>
							<?php
						endwhile;
						wp_reset_postdata();
					?>
					</div>
					<?php if ( ! empty( $button_label ) ) : ?>
						<div class="enterpriseup-gallery-view-all enterpriseup-button">
							<a href="<?php echo esc_url( $button_link ); ?>"><?php echo esc_html( $button_label ); ?></a>
						</div>
					<?php endif; ?>
				</div>
			</div>
		</section>
		<?php
	endif;
}
